@@ -5,7 +5,7 @@ from marshy.factory.enum_marshaller_factory import EnumMarshallerFactory
 from marshy.factory.list_marshaller_factory import ListMarshallerFactory
 from marshy.factory.optional_marshaller_factory import OptionalMarshallerFactory
 from marshy.factory.union_marshaller_factory import UnionMarshallerFactory
-from marshy.marshaller import none_marshaller, bool_marshaller
+from marshy.marshaller import none_marshaller, bool_marshaller, datetime_marshaller
 from marshy.marshaller.as_str_marshaller import AsStrMarshaller
 from marshy.marshaller_context import MarshallerContext
 from marshy.marshaller.primitive_marshaller import PrimitiveMarshaller
@@ -19,6 +19,7 @@ def new_default_context() -> MarshallerContext:
         context.register_marshaller(AsStrMarshaller(t))
     context.register_marshaller(none_marshaller)
     context.register_marshaller(bool_marshaller)
+    context.register_marshaller(datetime_marshaller)
     context.register_factory(EnumMarshallerFactory())
     context.register_factory(UnionMarshallerFactory())
     context.register_factory(OptionalMarshallerFactory())
